/**
  * This processing sketch randomly plays back video excerpts from D.W. Griffith’s film “Abraham Lincoln” - http://www.archive.org/details/abraham_lincoln. It creates non-linear and possibly new interpretations of Lincoln’s life through recombinant strategies.
  *
  * How it works:
  * Pressing a pushbutton connected to the Arduino board randomly plays one of six videos. The video playback stops at the end of the video and the Processing sketch waits for the next button push to play another randomly chosen video.
  *
  * You will need to install the jmcvideo library for Quicktime video playback. More information on this installation and the download of the library can be found here:
  * http://www.mat.ucsb.edu/~a.forbes/PROCESSING/jmcvideo/jmcvideo.html
  *
  * This example is based on the VideoSwitchGL example by Angus Forbes
  * copyleft, 2011: Fabian Winkler
  *
 */
 
import cc.arduino.*;
import processing.serial.*;
import jmcvideo.*;
import processing.opengl.*;
import javax.media.opengl.*; 

Arduino arduino;
JMCMovie myMovie;
int pvw, pvh;
int val = 0;
int oldval = 0;

// change the following code line to put in your own videos,
// don't forget to put them into the sketches' "data" folder
String[] vids = new String[]{"lincoln_01.mov", "lincoln_02.mov", "lincoln_03.mov", "lincoln_04.mov", "lincoln_05.mov", "lincoln_06.mov"};
int vidNum = 0;

void setup() {
  size(320, 240, OPENGL);
  frame.setResizable(true);
  background(0);
  
  println(Arduino.list());    
  arduino = new Arduino(this, Arduino.list()[8], 57600);  
  arduino.pinMode(2, Arduino.INPUT);
  
  // always start out with video number 1:
  myMovie = movieFromDataPath(vids[vidNum]); 
  myMovie.play();
}

void draw() {
val = arduino.digitalRead(2);
  
  // make sure we only trigger the video switch once
  // when the pushbutton is pressed & held down
  if (val != oldval && val == 1) {

     //create random numbers from 0 to (the amount of videos imported) -1
     vidNum = (int)random(vids.length);
     // switch video to the number randomly generated
     myMovie.switchVideo(vids[vidNum]); 
  }
  
  // start playing the video when the push button is released
  if (val != oldval && val == 0) {
    myMovie.play(); 
  }
 
  oldval = val;
  image(myMovie, 0, 0);
  //set playback speed based on mouse position
  myMovie.setRate (((width/2.0-mouseX)/(width/2.0))*3.0);
} 



JMCMovie movieFromDataPath(String filename)
{
  return new JMCMovie(this, filename, RGB);
}







